@@ -287,6 +287,71 @@ class PyProjectValidator(BaseValidator):
         "requires-python", "license", "dependencies"
     ]
     
+    # Build backend metadata version support
+    BUILD_BACKEND_METADATA_VERSIONS = {
+        "setuptools.build_meta": "2.1",  # setuptools supports metadata 2.1
+        "hatchling.build": "2.4",        # hatchling supports metadata 2.4
+        "poetry.core.masonry.api": "2.4", # poetry supports metadata 2.4
+        "pdm.backend": "2.4",            # pdm supports metadata 2.4
+        "flit.buildapi": "2.4",          # flit supports metadata 2.4
+    }
+    
+    # Metadata version requirements for different features
+    METADATA_VERSION_FEATURES = {
+        "license-file": "2.4",  # license-file requires metadata version 2.4+
+        "dynamic": "2.2",       # dynamic fields require metadata version 2.2+
+        "scripts": "2.1",       # Entry points in pyproject.toml require 2.1+
+        "dependencies": "2.1",  # Dependencies in pyproject.toml require 2.1+
+        "optional-dependencies": "2.1",  # Optional dependencies require 2.1+
+    }
+    
+    def _get_backend_metadata_version(self, backend: str) -> str:
+        """Get the metadata version supported by a build backend.
+        
+        Args:
+            backend: Build backend name
+        
+        Returns:
+            Metadata version supported by the backend
+        """
+        # Get the base backend name without parameters
+        base_backend = backend.split(":")[0]
+        return self.BUILD_BACKEND_METADATA_VERSIONS.get(base_backend, "2.1")  # Default to 2.1 for unknown backends
+    
+    def _check_metadata_compatibility(self, config: Dict[str, Any]) -> None:
+        """Check if the package metadata is compatible with the build backend.
+        
+        Args:
+            config: pyproject.toml configuration
+        
+        Raises:
+            ReleaseError: If metadata is incompatible with build backend
+        """
+        backend = config["build-system"]["build-backend"]
+        backend_metadata_version = self._get_backend_metadata_version(backend)
+        project = config.get("project", {})
+        
+        # Convert version strings to tuples for comparison
+        backend_version = tuple(map(int, backend_metadata_version.split(".")))
+        
+        for feature, required_version in self.METADATA_VERSION_FEATURES.items():
+            required_version_tuple = tuple(map(int, required_version.split(".")))
+            
+            if feature in project and backend_version < required_version_tuple:
+                raise ReleaseError(
+                    ErrorCode.PYPI_VALIDATION_ERROR,
+                    f"The '{feature}' field requires metadata version {required_version} but build backend '{backend}' only supports {backend_metadata_version}",
+                    fix_instructions=[
+                        "Either:",
+                        f"1. Update your build backend to one that supports metadata {required_version}+",
+                        "   - hatchling (recommended)",
+                        "   - poetry.core.masonry.api",
+                        "   - flit.buildapi",
+                        f"2. Remove or modify the '{feature}' field to be compatible with metadata {backend_metadata_version}",
+                        "3. Use an alternative configuration format supported by your current build backend"
+                    ]
+                )
+    
     def validate(self) -> None:
         """Validate pyproject.toml configuration.
         
@@ -346,6 +411,9 @@ class PyProjectValidator(BaseValidator):
                 ErrorCode.VERSION_INVALID,
                 f"Invalid version format: {version}. Must be in format X.Y.Z"
             )
+        
+        # Check metadata compatibility with build backend
+        self._check_metadata_compatibility(config)
 
 
 class PackageStructureValidator(BaseValidator):
@@ -361,7 +429,7 @@ class PackageStructureValidator(BaseValidator):
         src_dir = self.workspace_dir / "src"
         if not src_dir.exists():
             raise ReleaseError(
-                ErrorCode.PKG_STRUCTURE_INVALID,
+                ErrorCode.SRC_DIR_NOT_FOUND,
                 "src directory not found",
                 fix_instructions=[
                     "Create a src directory in your project root",
@@ -379,7 +447,7 @@ class PackageStructureValidator(BaseValidator):
         package_dir = src_dir / package_name.replace("-", "_")
         if not package_dir.exists():
             raise ReleaseError(
-                ErrorCode.PKG_STRUCTURE_INVALID,
+                ErrorCode.PACKAGE_DIR_NOT_FOUND,
                 f"Package directory {package_dir} not found",
                 fix_instructions=[
                     f"Create directory src/{package_name}",
@@ -391,7 +459,7 @@ class PackageStructureValidator(BaseValidator):
         init_file = package_dir / "__init__.py"
         if not init_file.exists():
             raise ReleaseError(
-                ErrorCode.PKG_FILE_MISSING,
+                ErrorCode.INIT_PY_NOT_FOUND,
                 f"__init__.py not found in {package_dir}",
                 fix_instructions=[
                     f"Create {init_file} file",
@@ -420,7 +488,7 @@ class RequiredFilesValidator(BaseValidator):
             file_path = self.workspace_dir / filename
             if not file_path.exists():
                 raise ReleaseError(
-                    ErrorCode.PKG_FILE_MISSING,
+                    ErrorCode.PACKAGE_VALIDATION_ERROR,
                     f"Required file {filename} not found",
                     fix_instructions=[
                         f"Create {filename} in your project root",
@@ -506,12 +574,23 @@ class EntryPointValidator(BaseValidator):
             file_path = file_path.with_suffix(".py")
             
             if not file_path.exists():
+                package_name = config["project"]["name"].replace("-", "_")
                 raise ReleaseError(
-                    ErrorCode.PKG_FILE_MISSING,
+                    ErrorCode.PACKAGE_VALIDATION_ERROR,
                     f"Entry point module not found: {file_path}",
                     fix_instructions=[
-                        f"Create module {module_path}",
-                        f"Implement function {func_name}"
+                        f"Create the module file at: {file_path}",
+                        f"Or update the entry point in pyproject.toml to point to an existing module",
+                        "",
+                        "Example module structure:",
+                        f"src/{package_name}/",
+                        "├── __init__.py",
+                        f"└── {module_parts[-1]}.py  # Create this file",
+                        "",
+                        f"Example {module_parts[-1]}.py content:",
+                        "def " + func_name + "():",
+                        '    print("Hello from CLI!")',
+                        "    return 0"
                     ]
                 )
 
